pub struct ControlEnvelope {
pub properties: Value,
}Fields
properties: ValueTrait Implementations
Sourceimpl Clone for ControlEnvelope
impl Clone for ControlEnvelope
Sourcefn clone(&self) -> ControlEnvelope
fn clone(&self) -> ControlEnvelope
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ControlEnvelope
impl Debug for ControlEnvelope
Sourceimpl<'de> Deserialize<'de> for ControlEnvelope
impl<'de> Deserialize<'de> for ControlEnvelope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ControlEnvelope
impl PartialEq for ControlEnvelope
Sourceimpl Serialize for ControlEnvelope
impl Serialize for ControlEnvelope
Sourceimpl TryFrom<&CallAnswer> for ControlEnvelope
impl TryFrom<&CallAnswer> for ControlEnvelope
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<&CallEnd> for ControlEnvelope
impl TryFrom<&CallEnd> for ControlEnvelope
Sourceimpl TryFrom<&CallOffer> for ControlEnvelope
impl TryFrom<&CallOffer> for ControlEnvelope
Sourceimpl TryFrom<&CallStats> for ControlEnvelope
impl TryFrom<&CallStats> for ControlEnvelope
Sourceimpl TryFrom<&CallTransportUpdate> for ControlEnvelope
impl TryFrom<&CallTransportUpdate> for ControlEnvelope
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<&ControlEnvelope> for CallAnswer
impl TryFrom<&ControlEnvelope> for CallAnswer
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<&ControlEnvelope> for CallEnd
impl TryFrom<&ControlEnvelope> for CallEnd
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<&ControlEnvelope> for CallOffer
impl TryFrom<&ControlEnvelope> for CallOffer
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<&ControlEnvelope> for CallStats
impl TryFrom<&ControlEnvelope> for CallStats
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<&ControlEnvelope> for CallTransportUpdate
impl TryFrom<&ControlEnvelope> for CallTransportUpdate
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<CallAnswer> for ControlEnvelope
impl TryFrom<CallAnswer> for ControlEnvelope
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<CallEnd> for ControlEnvelope
impl TryFrom<CallEnd> for ControlEnvelope
Sourceimpl TryFrom<CallOffer> for ControlEnvelope
impl TryFrom<CallOffer> for ControlEnvelope
Sourceimpl TryFrom<CallStats> for ControlEnvelope
impl TryFrom<CallStats> for ControlEnvelope
Sourceimpl TryFrom<CallTransportUpdate> for ControlEnvelope
impl TryFrom<CallTransportUpdate> for ControlEnvelope
Sourcetype Error = CodecError
type Error = CodecError
The type returned in the event of a conversion error.
impl Eq for ControlEnvelope
impl StructuralPartialEq for ControlEnvelope